import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import { useEffect, useState } from 'react';

function loadFromStorage(key) {
  var value = localStorage.getItem(key);

  if (value === null) {
    return value;
  }

  try {
    return JSON.parse(value);
  } catch (e) {
    console.error("[useStorageState] unexpected json ".concat(value), e);
    return null;
  }
}

function isFunction(v) {
  return typeof v === 'function';
}

export default function useStorageState(key, initialState) {
  function getInitialState() {
    var localValue = loadFromStorage(key);

    if (localValue === null && initialState) {
      return isFunction(initialState) ? initialState() : initialState;
    }

    return localValue;
  }

  var _useState = useState(getInitialState),
      _useState2 = _slicedToArray(_useState, 2),
      state = _useState2[0],
      setState = _useState2[1];

  useEffect(function () {
    setState(getInitialState());
  }, [key]);

  function updateState(updater) {
    setState(function (prev) {
      var nextState = isFunction(updater) ? updater(prev) : updater;
      localStorage.setItem(key, JSON.stringify(nextState));
      return nextState;
    });
  }

  return [state, updateState];
}