"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = useStorageState;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = require("react");

function loadFromStorage(key) {
  var value = localStorage.getItem(key);

  if (value === null) {
    return value;
  }

  try {
    return JSON.parse(value);
  } catch (e) {
    console.error("[useStorageState] unexpected json ".concat(value), e);
    return null;
  }
}

function isFunction(v) {
  return typeof v === 'function';
}

function useStorageState(key, initialState) {
  function getInitialState() {
    var localValue = loadFromStorage(key);

    if (localValue === null && initialState) {
      return isFunction(initialState) ? initialState() : initialState;
    }

    return localValue;
  }

  var _useState = (0, _react.useState)(getInitialState),
      _useState2 = (0, _slicedToArray2["default"])(_useState, 2),
      state = _useState2[0],
      setState = _useState2[1];

  (0, _react.useEffect)(function () {
    setState(getInitialState());
  }, [key]);

  function updateState(updater) {
    setState(function (prev) {
      var nextState = isFunction(updater) ? updater(prev) : updater;
      localStorage.setItem(key, JSON.stringify(nextState));
      return nextState;
    });
  }

  return [state, updateState];
}